<template>
  <div class="mod-config">
    <basic-container>
      <el-form :inline="true" :model="dataForm" @keyup.enter.native="getDataList()">
        <el-form-item>
          <el-button v-if="permissions.generator_administrativepenaltyfiles_add" icon="el-icon-plus" type="primary" @click="addOrUpdateHandle()">新增</el-button>
        </el-form-item>
      </el-form>

      <div class="avue-crud">
        <el-table
          :data="dataList"
          border
          v-loading="dataListLoading">
          <el-table-column
            prop="id"
            header-align="center"
            align="center"
            label="编号">
          </el-table-column>
          <el-table-column
            prop="name"
            header-align="center"
            align="center"
            label="文件名称">
          </el-table-column>
          <el-table-column
            prop="caseName"
            header-align="center"
            align="center"
            label="案件名称（主体加案由）">
          </el-table-column>
          <el-table-column
            prop="administrativeid"
            header-align="center"
            align="center"
            label="行政处罚决定书文号">
          </el-table-column>
          <el-table-column
            prop="companyName"
            header-align="center"
            align="center"
            label="办案单位名称">
          </el-table-column>
          <el-table-column
            prop="companyId"
            header-align="center"
            align="center"
            label="办案单位编号">
          </el-table-column>
          <el-table-column
            prop="filingPersonId"
            header-align="center"
            align="center"
            label="立卷人编号">
          </el-table-column>
          <el-table-column
            prop="filingPersonName"
            header-align="center"
            align="center"
            label="立卷人名称">
          </el-table-column>
          <el-table-column
            prop="fileTime"
            header-align="center"
            align="center"
            label="归档时间">
          </el-table-column>
          <el-table-column
            prop="beginTime"
            header-align="center"
            align="center"
            label="开始时间">
          </el-table-column>
          <el-table-column
            prop="endTime"
            header-align="center"
            align="center"
            label="结束时间">
          </el-table-column>
          <el-table-column
            prop="safekeepingDays"
            header-align="center"
            align="center"
            label="保管期限">
          </el-table-column>
          <el-table-column
            prop="pieceNum"
            header-align="center"
            align="center"
            label="共几件">
          </el-table-column>
          <el-table-column
            prop="pageNum"
            header-align="center"
            align="center"
            label="共几页">
          </el-table-column>
          <el-table-column
            prop="fileNum"
            header-align="center"
            align="center"
            label="归档号">
          </el-table-column>
          <el-table-column
            prop="createTime"
            header-align="center"
            align="center"
            label="创建时间">
          </el-table-column>
          <el-table-column
            prop="updateTime"
            header-align="center"
            align="center"
            label="修改时间">
          </el-table-column>
          <el-table-column
            header-align="center"
            align="center"
            label="操作">
            <template slot-scope="scope">
              <el-button v-if="permissions.generator_administrativepenaltyfiles_edit" type="text" size="small" icon="el-icon-edit" @click="addOrUpdateHandle(scope.row.id)">修改</el-button>
              <el-button v-if="permissions.generator_administrativepenaltyfiles_del" type="text" size="small" icon="el-icon-delete" @click="deleteHandle(scope.row.id)">删除</el-button>
            </template>
          </el-table-column>
        </el-table>
      </div>

      <div class="avue-crud__pagination">
        <el-pagination
          @size-change="sizeChangeHandle"
          @current-change="currentChangeHandle"
          :current-page="pageIndex"
          :page-sizes="[10, 20, 50, 100]"
          :page-size="pageSize"
          :total="totalPage"
          background
          layout="total, sizes, prev, pager, next, jumper">
        </el-pagination>
      </div>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form v-if="addOrUpdateVisible" ref="addOrUpdate" @refreshDataList="getDataList"></table-form>
    </basic-container>
  </div>
</template>

<script>
  import {fetchList, delObj} from '@/api/process/administrativepenaltyfiles'
  import TableForm from './administrativepenaltyfiles-form'
  import {mapGetters} from 'vuex'
  export default {
    data () {
      return {
        dataForm: {
          key: ''
        },
        dataList: [],
        pageIndex: 1,
        pageSize: 10,
        totalPage: 0,
        dataListLoading: false,
        addOrUpdateVisible: false
      }
    },
    components: {
      TableForm
    },
    created () {
      this.getDataList()
    },
    computed: {
      ...mapGetters(['permissions'])
    },
    methods: {
      // 获取数据列表
      getDataList () {
        this.dataListLoading = true
        fetchList(Object.assign({
          current: this.pageIndex,
          size: this.pageSize
        })).then(response => {
          this.dataList = response.data.data.records
          this.totalPage = response.data.data.total
        })
        this.dataListLoading = false
      },
      // 每页数
      sizeChangeHandle (val) {
        this.pageSize = val
        this.pageIndex = 1
        this.getDataList()
      },
      // 当前页
      currentChangeHandle (val) {
        this.pageIndex = val
        this.getDataList()
      },
      // 新增 / 修改
      addOrUpdateHandle (id) {
        this.addOrUpdateVisible = true
        this.$nextTick(() => {
          this.$refs.addOrUpdate.init(id)
        })
      },
      // 删除
      deleteHandle (id) {
        this.$confirm('是否确认删除ID为' + id, '提示', {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          type: 'warning'
        }).then(function () {
          return delObj(id)
        }).then(data => {
          this.$message.success('删除成功')
          this.getDataList()
        })
      }
    }
  }
</script>
